import { makeStyles } from "@material-ui/core/styles";
import SendIcon from '@mui/icons-material/Send';
import MicNoneIcon from '@mui/icons-material/MicNone';
import AttachFileIcon from '@mui/icons-material/AttachFile';
import SentimentSatisfiedAltIcon from '@mui/icons-material/SentimentSatisfiedAlt';
import ArrowDownwardIcon from '@mui/icons-material/ArrowDownward';
import Avatar from '@mui/material/Avatar';
import { useState } from "react";
import { useSelector } from "react-redux";
import { getState } from '../../../../../redux/authorization/selector'

import FilesMenu from "../FilesMenu";
import NotDone from "../../../../reusableComponents/NotDone";


const useStyles = makeStyles({   
    container: {
        display: "flex",
        justifyContent: "space-between",
        alignContent: 'flex-end',
        alignItems:'flex-end',
        width: 700,
        position: 'fixed',
        bottom: 20,
    },
    inputContainer: {
        position:'relative',
        minWidth: 634,
        maxWidth: 634,
        maxHeight:56,
        display: 'flex',
        flexWrap: 'nowrap',
        alignContent: 'center',
        alignItems: 'center',
        color: '#6b6b6b',
        backgroundColor: '#ffffff',
        borderRadius: 8,
        padding: 10,
        marginRight: 10,
      "&:after": {
        content: "''",
        position: "absolute",
        width: "0",
        height: "0",
        borderBottom: "15px solid #ffffff",
        borderLeft: "15px solid transparent",
        borderRight: "15px solid transparent",
        bottom: "0",
        right: "-15px"
      },
      "&:before": {
        content: "''",
        position: "absolute",
        width: "0",
        height: "0",
        borderBottom: "17px solid #ffffff",
        borderLeft: "16px solid transparent",
        borderRight: "16px solid transparent",
        bottom: "-1px",
        right: "-17px"
      }        
    },
    textarea: {
        minWidth: 550,
        maxWidth: 550,
        outline: 'none',
        border:'none',
        padding: '0px 10px',
        marginLeft: 8,
        marginRight: 8,
        overflowY:'auto',
        resize: 'none',
        height: 'auto',
    },
    attachIcon: {
        height:'auto',
        '&:hover': {
            color: 'rgb(41, 139, 231)',
        }        
    },
    filesMenu: {
      background: '#fdfdfd',
      position: 'absolute',
      width: 230,
      maxWidth: '100%',
      left: 406,
      bottom:64,
      zIndex: 10,
      visibility: 'visible',
      borderRadius: 10,
      padding: '4px 6px',
    },
    emoji: {
      background: '#fdfdfd',
      position: 'absolute',
      width: 350,
      height:350,
      left: 0,
      bottom:64,
      zIndex: 10,
      visibility: 'visible',
      borderRadius: 10,
      padding: '0px 6px',
    },     
    avatar: {
        '&:hover': {
            backgroundColor: 'rgb(41, 139, 231)',
            color: '#ffffff',
        }
    },
    avatarArrow: {
        left: 120,
        bottom:200,
        '&:hover': {
            backgroundColor: 'rgb(41, 139, 231)',
            color: '#ffffff',
        }
    },    
});

interface ISendMessage{
    setChat:any,
    isArrow:boolean,
    handleArrow:() => void
}

const SendMessage = ({setChat,isArrow,handleArrow}:ISendMessage) => {
    const classes = useStyles();
    const currentUser = useSelector(getState)
    const [value, setValue] = useState<string>('')
    const [isOpenMenu, setIsOpenMenu] = useState<boolean>(false)
    const [isOpenEmoji, setIsOpenEmoji] = useState<boolean>(false)
    const sentMessage = () => {
        const {name ,lastName,avatarUrl} = currentUser
        const newMessage =  {
        avatarUrl:`http://${avatarUrl}`,
        name,
        lastName,
        message: value,
        }
        setChat((prevState: any) => [...prevState, newMessage])
        setValue('')
        setIsOpenMenu(false)
        setIsOpenEmoji(false)        
    }    
    const handleTextarea = (e: React.ChangeEvent<HTMLTextAreaElement>) => {
        setIsOpenMenu(false)
        setIsOpenEmoji(false)
        setValue(e.target.value.trim())
    }
    const handleFocusTextarea = () => {
        setIsOpenMenu(false)
        setIsOpenEmoji(false)
    }
    const handleLeaveInput = (e: any) => {
        if (e.clientX > 1450 || e.clientX < 850) {
        setIsOpenMenu(false)
        setIsOpenEmoji(false) 
        }
    }
    const handleMoveInput = (e: any) => {
        if (e.clientX < 1250 && e.clientX > 1200) {
        setIsOpenMenu(false)
        setIsOpenEmoji(false)  
        }
    }
    const handleKeyPres = (e: any) => {
        console.log(value.length)
        if(e.code === 'Enter'&& value) sentMessage()
    }
    const handleEnterFileMenu = () => setIsOpenMenu(true)
    const handleLeaveFileMenu = () => setIsOpenMenu(false)
    const handleEnterEmoji = () => setIsOpenEmoji(true)
    const handleLeaveEmoji = () => setIsOpenEmoji(false)  


    return (
        <div className={classes.container} >            
            <div onMouseLeave={handleLeaveInput} onMouseMove={handleMoveInput}
                 onKeyPress={handleKeyPres} className={classes.inputContainer}>
                <SentimentSatisfiedAltIcon onMouseEnter={handleEnterEmoji}
                    fontSize='medium' sx={{ color: isOpenEmoji ? 'rgb(41, 139, 231)' : '#6b6b6b' }} />
                <div onMouseLeave={handleLeaveEmoji} style={{display:isOpenEmoji?'block':'none'}} className={classes.emoji}>
                    <NotDone name='Emoji Bar'/>
                </div>                
                <textarea value={value} onFocus={handleFocusTextarea} onChange={handleTextarea} className={classes.textarea}
                  placeholder='Message' rows={1}></textarea>
                <AttachFileIcon onMouseEnter={handleEnterFileMenu} 
                    className={classes.attachIcon}
                    fontSize='medium'  sx={{color: isOpenMenu?'rgb(41, 139, 231)':'#6b6b6b'}}/>
                <div onMouseLeave={handleLeaveFileMenu} style={{display:isOpenMenu?'block':'none'}} className={classes.filesMenu}>
                    <FilesMenu setIsOpenMenu={setIsOpenMenu}/>
                </div>
                <Avatar onClick={handleArrow} className={classes.avatarArrow} sx={{
                  backgroundColor: '#ffffff',
                   width: 56, height: 56 ,color: '#6b6b6b',display:isArrow?'flex':'none'}}>
                  <ArrowDownwardIcon fontSize="medium" />
                </Avatar>                 
            </div>  
            {value ?
             <Avatar onClick={sentMessage} className={classes.avatar} sx={{
               backgroundColor: '#ffffff',
               width: 56, height: 56 ,color: 'rgb(41, 139, 231)'}}>
                  <SendIcon fontSize="medium" />
                </Avatar> :
             <Avatar className={classes.avatar} sx={{
               backgroundColor: '#ffffff',
                    width: 56, height: 56, color: '#6b6b6b'}}>                   
                    <MicNoneIcon fontSize="medium" />                    
            </Avatar>}
        </div>            
    )
}

export default SendMessage